import _extends from "@babel/runtime/helpers/esm/extends";

var _storedInfo;

import { utils } from './middlewares/source/pageReferrer.js';
import { getConfig } from './config.js';
var FIELDS = {
  clientId: 'client_id',
  sessionId: 'session_id'
};
var STC = {
  QUERY: 'stc',
  SPLIT_SYMBOL: '-',
  NAME_SPLIT_SYMBOL: ':'
};
var STC_MEDIUM_TRANSFORMATIONS = {
  aff: 'affiliate',
  dis: 'display',
  em: 'email',
  met: 'paid-metasearch',
  sem: 'paid-search',
  rt: 'display',
  sm: 'social-media',
  sp: 'paid-social',
  pn: 'push-notification',
  cs: 'cross-sites'
};
var storedInfo = (_storedInfo = {}, _storedInfo[FIELDS.clientId] = null, _storedInfo[FIELDS.sessionId] = null, _storedInfo);

var loadScript = function loadScript(src) {
  return new Promise(function (resolve, reject) {
    var s = document.createElement('script');
    s.src = src;
    s.onload = resolve;
    s.onerror = reject;
    document.head.appendChild(s);
  });
};

export var loadGoogleAnalytics = function loadGoogleAnalytics() {
  var googleAnalyticsMeasurementId = getConfig('googleAnalyticsMeasurementId'); // 1. Check we have the needed config to load the script

  if (!googleAnalyticsMeasurementId) return Promise.resolve(false); // 2. Create Gtag script

  var gtagScript = "https://www.googletagmanager.com/gtag/js?id=" + googleAnalyticsMeasurementId; // 3. Load Gtag and retrieve async clientId from Google

  return loadScript(gtagScript);
};

var getGoogleField = function getGoogleField(field) {
  var googleAnalyticsMeasurementId = getConfig('googleAnalyticsMeasurementId'); // If googleAnalyticsMeasurementId is not present, then don't load anything

  if (!googleAnalyticsMeasurementId) return Promise.resolve();
  return new Promise(function (resolve) {
    // try to get the field from the stored info
    if (storedInfo[field]) return resolve(storedInfo[field]); // if not, get from the GoogleAnalytics tag

    window.gtag == null ? void 0 : window.gtag('get', googleAnalyticsMeasurementId, field, function (id) {
      // store locally field value
      storedInfo[field] = id; // resolve the promise with the field

      resolve(id);
    });
  });
};

export var setGoogleConsentMode = function setGoogleConsentMode(hasConsents) {
  var value = hasConsents ? 'granted' : 'denied';
  window.gtag == null ? void 0 : window.gtag('consent', 'update', {
    analytics_storage: value,
    ad_storage: value
  });
  window.gtag == null ? void 0 : window.gtag('set', {
    allow_google_signals: hasConsents,
    restricted_data_processing: !hasConsents
  });
};
export var getCampaignDetails = function getCampaignDetails(_temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      _ref$needsTransformat = _ref.needsTransformation,
      needsTransformation = _ref$needsTransformat === void 0 ? true : _ref$needsTransformat;

  var search = utils.getActualQueryString();
  var searchParams = new URLSearchParams(search);
  if (!searchParams.has(STC.QUERY)) return null;
  var stc = searchParams.get(STC.QUERY);

  var _stc$split = stc.split(STC.SPLIT_SYMBOL),
      medium = _stc$split[0],
      source = _stc$split[1],
      originalName = _stc$split[2],
      term = _stc$split[3],
      content = _stc$split[4];

  var _originalName$split = originalName.split(STC.NAME_SPLIT_SYMBOL),
      id = _originalName$split[0],
      name = _originalName$split[1];

  return {
    campaign: _extends({
      medium: needsTransformation && STC_MEDIUM_TRANSFORMATIONS[medium] || medium
    }, typeof name !== 'undefined' && {
      id: id
    }, {
      name: name != null ? name : id,
      source: source,
      term: term
    }, typeof content !== 'undefined' && {
      content: content
    })
  };
};
export var getGoogleClientID = function getGoogleClientID() {
  return getGoogleField(FIELDS.clientId);
};
export var getGoogleSessionID = function getGoogleSessionID() {
  return getGoogleField(FIELDS.sessionId);
};