import _extends from "@babel/runtime/helpers/esm/extends";
import './patchAnalytics.js';
import { campaignContext } from './middlewares/source/campaignContext.js';
import { defaultContextProperties } from './middlewares/source/defaultContextProperties.js';
import { pageReferrer } from './middlewares/source/pageReferrer.js';
import { userScreenInfo } from './middlewares/source/userScreenInfo.js';
import { userTraits } from './middlewares/source/userTraits.js';
import { getConfig, isClient } from './config.js';
import { getCampaignDetails, loadGoogleAnalytics } from './googleRepository.js';
import analytics from './segmentWrapper.js';
import initTcfTracking from './tcf.js';
import { getUniversalIdAndNotify } from './universalId.js';
/* Initialize TCF Tracking with Segment */

initTcfTracking();
/* Generate UniversalId if available */

try {
  getUniversalIdAndNotify();
} catch (e) {
  console.error("[segment-wrapper] UniversalID couldn't be initialized"); // eslint-disable-line
}
/* Initialize middlewares */


var addMiddlewares = function addMiddlewares() {
  window.analytics.addSourceMiddleware(userTraits);
  window.analytics.addSourceMiddleware(defaultContextProperties);
  window.analytics.addSourceMiddleware(campaignContext);
  window.analytics.addSourceMiddleware(userScreenInfo);
  window.analytics.addSourceMiddleware(pageReferrer);
};
/* Initialize Segment on Client */


if (isClient && window.analytics) {
  /* Initialize Google Analtyics if needed */
  var googleAnalyticsMeasurementId = getConfig('googleAnalyticsMeasurementId');

  if (googleAnalyticsMeasurementId) {
    var googleAnalyticsConfig = getConfig('googleAnalyticsConfig');
    window.dataLayer = window.dataLayer || [];

    window.gtag = window.gtag || function gtag() {
      window.dataLayer.push(arguments);
    };

    window.gtag_enable_tcf_support = true;
    window.gtag('js', new Date());
    var campaignDetails = getCampaignDetails();
    window.gtag('config', googleAnalyticsMeasurementId, _extends({
      cookie_prefix: 'segment',
      send_page_view: false
    }, googleAnalyticsConfig, campaignDetails));
    window.gtag('event', 'adevinta');
    loadGoogleAnalytics();
  }

  window.analytics.addSourceMiddleware ? addMiddlewares() : window.analytics.ready(addMiddlewares);
}

export default analytics;
export { getAdobeVisitorData, getAdobeMCVisitorID } from './adobeRepository.js';
export { getUniversalId } from './universalId.js';